<?php
/**
 * useful_plugins
 */
?>
<div id="useful_plugins" class="spicepress-tab-pane panel-close">
	<div class="container-fluid">
		<div class="row">
			<div class="col-md-6">
				<div class="spicepress-tab-pane-half m-top-40">
					<h3><i class="dashicons dashicons-sos"></i><?php esc_html_e('Contact Support','spicepress' ); ?></h3>
					<p><?php esc_html_e('We want to make sure you have the best experience using this theme, and that is why we have gathered all the necessary information here for you. We hope you will enjoy using this theme as much as we enjoy creating great products.','spicepress' ); ?></p>
					<p><a target="_blank" href="<?php echo esc_url('https://spicethemes.com/contact/'); ?>" class="button button-primary"><?php esc_html_e('Contact Support','spicepress'); ?></a></p>
				</div>
			</div>
			<div class="col-md-6">
				<div class="spicepress-tab-pane-half m-top-40">
					<h3><i class="dashicons dashicons-portfolio"></i><?php esc_html_e('Changelog','spicepress' ); ?></h3>
					<p><?php esc_html_e( 'Want to get the list of the latest theme changes? Just consult our changelog below to get a taste of the recent fixes and features implemented.', 'spicepress' ); ?></p>
					<p><a target="_blank" href="<?php echo esc_url('https://spicethemes.com/spicepress-changelog/'); ?>"><?php esc_html_e('Changelog','spicepress'); ?></a></p>
				</div>
			</div>
			<div class="clearfix"></div>
		</div>
	</div>
</div>