.spicepress-nav-tabs {
    margin: 30px 0 0;
    border-bottom: 1px solid #dedede;
    padding-left: 0rem;
}
.spicepress-nav-tabs:after {
    clear: both;
    display: table;
    content: " ";
}
.spicepress-nav-tabs > li {
    float: left;
    margin-bottom: -1px;
    display: block;
}
.spicepress-nav-tabs > li.active > a, .spicepress-nav-tabs > li.active > a:focus, .spicepress-nav-tabs > li.active > a:hover {
    background: #fff;
    border-bottom-color: #fff;
    color: #00a4e7;
    border-bottom-color: transparent;
}
.spicepress-nav-tabs li:last-child .nav-tab {
    border-right: 1px solid #ccc;
}
.spicepress-nav-tabs > li.spicepress-w-red-tab > a {
    color: red;
    font-weight: bold;
}
.spicepress-tab-content {
	background-color: #fff;
    /* border-bottom: 1px solid #ddd;
    border-right: 1px solid #ddd;
    border-left: 1px solid #ddd;
    width: 1400px;
    float: left; */
}
.spicepress-tab-content > .tab-pane {
    display: none;
}
.spicepress-tab-content > .active {
    display: block;
}

/* .spicepress-tab-pane { */
	/* padding: 30px; */
/* } */

.spicepress-tab-pane.active {
    display: block;
}

#spicepress-theme-version {
    font-size: 50%;
    padding: 10px;
    background: #ccc;
}
#spicepress-w-screenshot {
    border: 1px solid #ccc;
    margin-top: 30px;
}
.spicepress-w-activated {
    cursor:not-allowed !important;
}
.spicepress-tab-pane-half {
    /* width: 45%; */
    /* float:left; */
    padding-left: 20px;
    margin-top: 15px;
    padding-right: 20px;
    margin-bottom: 15px;
}
.spicepress-tab-content img {
    max-width: 100%;
}
.spicepress-pane-first-half {
    border-left: none;
}
.spicepress-pane-center {
    text-align: center;
    margin-bottom: 30px;
    margin-top: 30px;
	border-bottom: 1px solid #eaeaea;
}

.spicepress-tab-center {
    text-align: center;
    margin-bottom: 30px;
    margin-top: 30px;
	border-bottom: 1px solid #eaeaea;
}

.spicepress-info-title {
    font-size: 32px !important;
	border-bottom: 1px solid #eaeaea;
	line-height:50px !important;
}
.spicepress-clear {
    clear: both;
}
.spicepress-child-theme-container {
    position: relative;
}
.spicepress-child-theme-description {
    position: absolute;
    top: 100%;
    left: 0;
    overflow: auto;
    box-sizing: border-box;
    padding: 0;
    max-width: 100%;
    height: 100%;
    background-color: #000000;
    color: #ffffff;
    -webkit-transition: all 300ms ease-out;
    -moz-transition: all 300ms ease-out;
    -ms-transition: all 300ms ease-out;
    -o-transition: all 300ms ease-out;
    transition: all 300ms ease-out;
    -webkit-transition-delay: 500ms;
    -moz-transition-delay: 500ms;
    -ms-transition-delay: 500ms;
    -o-transition-delay: 500ms;
    transition-delay: 500ms;
}

.spicepress-child-theme-image-container {
    position: relative;
    overflow: hidden;
}
.spicepress-child-theme-image-container img {
    max-width: 100%;
}
.spicepress-child-theme-details .theme-details {
    padding: 10px;
    background: none repeat scroll 0 0 #F1F1F1;
    font-size: 18px;
}

.spicepress-child-theme-details .theme-details.active {
    background: none repeat scroll 0 0 #2B5F87;
    color: #fff;
}

.spicepress-child-theme-details .theme-details .theme-name {
    float:left;
}
.spicepress-child-theme-details .theme-details .preview {
    margin-right: 2px;
}
.spicepress-fre-pro table {
    border-collapse: collapse;
    width: 100%;
}
.spicepress-fre-pro table tr {
    border-bottom: 1px solid #ddd;
}
.spicepress-fre-pro table td {
    padding: 30px;
	width: 25%;
    padding: 10px;
    color: #555;
    font-weight: bold;
    border-left: 2px solid #ebebeb;
	text-align:center;
}
}
.spicepress-fre-pro table th {
    padding-bottom: 30px;
	font-size:19px;
}
.spicepress-fre-pro table td span.dashicons-before:before {
    font-size: 50px;
    width: auto;
    height: auto;
}
.spicepress-fre-pro table td span.dashicons-yes:before {
    color:green;
}
.spicepress-fre-pro table td span.dashicons-no-alt:before {
    color:red;
}
.spicepress-fre-pro table tr.spicepress-text-center {
    text-align: center;
}
.spicepress-actions-count {
    padding: 0 6px;
    display: inline-block;
    background-color: #d54e21;
    color: #fff;
    font-size: 9px;
    line-height: 17px;
    font-weight: 600;
    margin: 1px 0 0 2px;
    vertical-align: top;
    -webkit-border-radius: 10px;
    border-radius: 10px;
    z-index: 26;
}
.spicepress-action-required-box {
    position: relative;
}
.spicepress-dismiss-required-action {
    position: absolute;
    top: 0px;
    right: 0px;
    cursor: pointer;
    background-color: #D24A4A;
    border-radius: 50%;
    color: #fff;
    font-size: 14px;
    line-height: 20px;
}
.spicepress-dismiss-required-action:hover {
    background-color: #CC8C8C;
}

#github.spicepress-lite-tab-pane {
  text-align: center;
}

#github.spicepress-lite-tab-pane .spicepress-tab-pane-half {
  min-height: 160px;
}

#github.spicepress-lite-tab-pane .translate-button, #github .github-button {
  margin-top: 20px;
}

#github.spicepress-lite-tab-pane .dashicons {
  color: #0073aa;
  font-size: 12px;
  width: auto;
}

#github.spicepress-lite-tab-pane h4 {
  margin:10px;;
}

#github.spicepress-lite-tab-pane p.review-link {
  margin:0;
}

#github.spicepress-lite-tab-pane .spicepress-tab-pane-half hr {
  display: none;
}

/*Breakpoints*/

}
@media (max-width: 782px) {
  #github.spicepress-tab-pane .spicepress-tab-pane-half hr {
    display:block;
  }

  .spicepress-tab-pane-half {
    width: auto;
    float: none;
    border-left: none;
  }
  .spicepress-welcome-title, .spicepress-tab-content h1 {
    line-height: 30px;
  }
  .spicepress-fre-pro table td {
    padding: 30px 10px;
  }
}

.spicepress-tab-pane-first-half p  
{
	font-size:17px;
}


.info-container {
    background-color: #fff;
    margin-right: 20px;
    padding: 60px 30px 90px;
    margin-top: 20px;
    border: 1px solid #e5e5e5;
    text-align: center;
}

.info-title {
    margin: 0 0 45px;
    text-transform: uppercase;
}

.info-block {
    float: left;
    width: 100%;
    border: 1px solid #eaeaea;
    padding: 25px 15px 15px;
    margin: 1%;
    background-color: #f7f7f7;
	text-align:center;
}

.info-icon {
    font-size: 34px;
    width: auto;
    height: auto;
}

.dashicons, .dashicons-before:before {
    display: inline-block;
    width: 20px;
    height: 20px;
    font-size: 20px;
    line-height: 1;
    font-family: dashicons;
    text-decoration: inherit;
    font-weight: 400;
    font-style: normal;
    vertical-align: top;
    text-align: center;
    -webkit-transition: color .1s ease-in 0;
    transition: color .1s ease-in 0;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

.info-text a {
    color: #444;
    text-decoration: none;
}
#free_pro th {font-size:30px; line-height: 40px;}

/* Free vs Pro */
/*===================================================================================*/
/*	PRICING TABLES TWO
/*===================================================================================*/
.pricing1 { margin-top: 40px;  }
.pricing h1, .pricing h2, .pricing h3, .pricing h4, .pricing h5, .pricing h6, 
.pricing1 h1, .pricing1 h2, .pricing1 h3, .pricing1 h4, .pricing1 h5, .pricing1 h6 { font-family: 'Signika', sans-serif; }
.pricing1 .plan {
	font-family: sans-serif;
	border-top-left-radius: 0px;
	border-top-right-radius: 0px;
	overflow: hidden;
	/* letter-spacing: 0.5px; */
	border-left: 1px solid #dddddd;
	border-top: 1px solid #dddddd;
	border-bottom: 1px solid #dddddd;
	border-right: 1px solid #dddddd;
}
.pricing1 .border-right { border-right: 1px solid #dddddd; }
.pricing1 .col-md-4:last-child .plan { border-right: 1px solid #dddddd; }
.pricing1 .plan .feature li:last-child { border-bottom: 0 none; } 
.pricing1 .plan header { background: #fff; text-align: center; }
.pricing1 .plan h2 { background: #f8f8f8; font-size: 24px; line-height: 30px; font-weight: 400; color: #333; padding: 15px 20px 15px; border-bottom: 1px solid #dddddd; margin: 0 !important; }
.pricing1 .plan h2 small { display: block; color: #808080; font-size: 14px; padding-top: 7px; }
.pricing1 .plan .btn { margin-bottom: 0; font-size: 16px; }
.pricing1 .plan .btn i { margin-right: 7px; }
.pricing1 .plan .price { margin-bottom: 15px; }
.pricing1 .plan .price { line-height: 100%; }
.pricing1 .plan .feature {
    background: #ffffff;
    padding: 0;
    margin: 0;
}
.pricing1 .plan .feature li { padding: 30px 20px; color: #333; font-size: 18px; border-bottom: 1px solid #dddddd;     height: 128px;
    margin-bottom: 0; }
.pricing1.col-3 .plan header { padding: 40px; }
.pricing1.col-3 .plan .feature { padding: 20px 30px; }
.pricing1 .plan .price1 {
    padding: 14px 10px 13px;
    text-align: center;
	border-bottom: 1px solid #dddddd;
    font-family: 'Signika', sans-serif;
    font-weight: 400;
    font-size: 50px;
    line-height: 56px;
    color: #2f4052;
    display: block;
	letter-spacing: 0;
}
.pricing1 .plan .price1 span { display: inline-block; margin-left: -12px; }
.pricing1 .plan .price1 span sup { position: relative; top: -0.6em; display: inline-block; padding: 0; font-size: 24px; }
.pricing1 .plan .duration { text-align: center; color: #636e79; display: block; font-size: 16px; line-height: 25px; margin-bottom: 5px; }
.pricing1 .col-md-3  { padding: 0; }
.pricing1 .offer-content { border-left: 1px solid #dddddd; border-top: 0 none; border-bottom: 1px solid #dddddd; border-right: 1px solid #dddddd; }
.pricing1 .most-popular {
    display: block;
    float: left;
    width: 100%;
    height: 36px;
    line-height: 36px;
    margin: -36px 0 0 0;
    text-align: center;
    text-transform: uppercase;
    color: #fff;
    background: #2f4052;
    font-size: 15px;
    border: 1px solid #dddddd;
    border-bottom: none;
	position: absolute;
    top: 0px;
    left: 0;
    right: 0;
}
.btn-wrap { display: block; border-bottom: 1px solid #dddddd; padding: 24px 0; }
.btn-wrap a.btn { margin-top: 0px; color: #e84a52; }
.btn-wrap a.btn i { margin-right: 10px; }

@media (max-width: 1024px) {

/*Pricing Table 1*/
.pricing1 .plan { border-right: 1px solid #dddddd; margin-bottom: 30px; }
.pricing-content { border-top: 1px solid #dddddd; }
.pricing1 .dashicons, .pricing1 .dashicons-before:before {
    font-size: 30px !important;
    line-height: 1 !important;
}

.pricing1 .plan .feature li 
{font-size:14px;font-weight:600;}

.pricing1 .plan .feature li p
{
	font-size:12px; font-weight:normal;
}

}

@media (max-width: 768px) {

.pricing1 .plan .feature li {
    height: auto !important;
}
}

.blank{
    background: transparent;
    
    
    padding: 10px 20px 15px;
    border: 0px none;
    padding-top:10px;
}
.border0 { border: 0 none; }
.red { color: red; } .green { color: green; }
.padding0 { padding: 0; }
.padding10 { padding: 15px; }
.margin56 { margin-top: 56px; }
.pricing1 .dashicons, .pricing1 .dashicons-before:before {
    display: inline-block;
    /* width: 35px;
    height: 35px; */
    font-size: 40px;
    line-height: 1.7;
    font-family: dashicons;
    text-decoration: inherit;
    font-weight: 400;
    font-style: normal;
    vertical-align: top;
    text-align: center;
    -webkit-transition: color .1s ease-in 0;
    transition: color .1s ease-in 0;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}
a.info-block{text-decoration:none;color:#333;}
a.info-block:hover, a.info-block:active, a.info-block:focus{color:#333;}
.wp-person a:focus .gravatar, a:focus, a:focus .media-icon img{ box-shadow:none !important; }

/*css 4 oct 18*/
.m-top-40 { margin-top: 40px; }
.m-top-40 p {font-size: 15px; }
.theme-info-wrap h3 { margin: 1.25em 0 .6em; }
.theme-info-wrap h3 > i { line-height: 1.2; margin-right: 15px }

.about-wrap{ margin: 25px 25px 0 20px; max-width: 100%;}
.spicepress-fre-pro span.plan-feature {
    line-height: 2.5rem;
}
@media only screen and (min-width: 769px) and (max-width: 1200px) {
.pricing1 .plan .feature li{
    height: 200px;
}
}


/*----------------------   New CSS for Starter Sites  --------------------------------------------------------------------------------------------------------*/

.recommended_box.col-md-6.col-sm-6.col-xs-12 {
    border: 2px solid #e5e5e5;
    padding: 16px;
    min-height: 180px;
}

/*aboutcss*/

.spice-starter-sites-importer-button.button-primary{
    margin: 30px 5px;
    padding: 8px 30px;
}
#myDiv,#myDivs2 {
    position: fixed;
    inset: 0;
    width: 100%;
    height: 100%;
    background-color: rgba(0, 0, 0, 0.9);
    z-index: 9999;
}
.spice-starter-sites-importer-loader{
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    color: #fff;
}
.block-container {
    width: 100%;
    padding-right: 15px;
    padding-left: 15px;
    margin-right: auto;
    margin-left: auto;
}

@media(min-width:600px) {
    .block-container {
        max-width: 600px;
    }
}

@media(min-width:768px) {
    .block-container {
        max-width: 768px;
    }
}

@media(min-width:992px) {
    .block-container {
        max-width: 992px;
    }
}

@media(min-width:1200px) {
    .block-container {
        max-width: 1200px;
    }
}

.block-row {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    margin-right: -15px;
    margin-left: -15px;
}

.block-col-2,
.block-col-3,
.block-col-4,
.block-col-5,
.block-col-6,
.block-col-7,
.block-col-8,
.block-col-9 {
    position: relative;
    width: 100%;
    min-height: 1px;
    padding-right: 15px;
    padding-left: 15px;
}

@media (min-width: 768px) {
    .block-col-1 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 8.333333%;
        flex: 0 0 8.333333%;
        max-width: 8.333333%;
    }

    .block-col-2 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 16.666667%;
        flex: 0 0 16.666667%;
        max-width: 16.666667%;
    }

    .block-col-3 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 25%;
        flex: 0 0 25%;
        max-width: 25%;
    }

    .block-col-4 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 33.333333%;
        flex: 0 0 33.333333%;
        max-width: 33.333333%;
    }

    .block-col-5 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 41.666667%;
        flex: 0 0 41.666667%;
        max-width: 41.666667%;
    }

    .block-col-6 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 50%;
        flex: 0 0 50%;
        max-width: 50%;
    }

    .block-col-7 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 58.333333%;
        flex: 0 0 58.333333%;
        max-width: 58.333333%;
    }

    .block-col-8 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 66.666667%;
        flex: 0 0 66.666667%;
        max-width: 66.666667%;
    }

    .block-col-9 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 75%;
        flex: 0 0 75%;
        max-width: 75%;
    }
}

@media (min-width: 576px) {
    .block-col-12 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 100%;
        flex: 0 0 100%;
        max-width: 100%;
    }
}
.block-col-2 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 25%;
    flex: 1;
    max-width: 50%;
}
/*.action-link.button {
    float: right;
}*/
table {
  border-collapse: collapse;
  width: 100%;
}

th, td {
  text-align: left;
  padding: 0 10px;
  margin: 12px auto;
}

tr:nth-child(even) {
    background-color: rgba(255, 255, 255,  0.6); 
}

#spice-starter-sites-importer-dashboard h3.spice-starter-sites-importer-heading,
.spice-starter-sites-importer-dashboard h3.spice-starter-sites-importer-heading{
    font-size: 2rem;
    line-height: 1.5;
    font-weight: 700;
    margin-bottom: 10px;
    color: #000;
    margin-top: 30px;
    text-align: center;
}
#spice-starter-sites-importer-dashboard .sss_template.open h3.spice-starter-sites-importer-heading{color: #fff;}
#spice-starter-sites-importer-dashboard p,.spice-starter-sites-importer-loader p{
    font-size: 18px;
}

#spice-starter-sites-importer-dashboard li{
    font-size: 16px;
    padding: 10px;
}
#spice-starter-sites-importer-dashboard li::marker{
    font-weight: 500;
}
.theme_info.info-tab-content .dashicons.dashicons-yes{
    color: #0d810d;
    font-size: 28px;
}

/* -------------------------------- 
  Spice Starter Sites Importer Popup 
-------------------------------- */
.spice-starter-sites-importer-popup {
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  background-color: rgba(0, 0, 0, 0.9);
  opacity: 0;
  visibility: hidden;
  -webkit-transition: opacity 0.3s 0s, visibility 0s 0.3s;
  -moz-transition: opacity 0.3s 0s, visibility 0s 0.3s;
  transition: opacity 0.3s 0s, visibility 0s 0.3s;
  z-index: 999999;
}
.spice-starter-sites-importer-popup.is-visible {
  opacity: 1;
  visibility: visible;
  -webkit-transition: opacity 0.3s 0s, visibility 0s 0s;
  -moz-transition: opacity 0.3s 0s, visibility 0s 0s;
  transition: opacity 0.3s 0s, visibility 0s 0s;
}

.spice-starter-sites-importer-popup-container {
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    padding: 53px 42px;
    width: 90%;
    max-width: 366px;
    background: #f3f9f9;
    border-radius: 6px;
    text-align: center;
    box-shadow: 0 0 20px rgba(0, 0, 0, 0.2);
    -webkit-backface-visibility: hidden;
    -webkit-transition-property: -webkit-transform;
    -moz-transition-property: -moz-transform;
    transition-property: transform;
    -webkit-transition-duration: 0.3s;
    -moz-transition-duration: 0.3s;
    transition-duration: 0.3s;
}
.spice-starter-sites-importer-popup-container p {
    font-size: 16px;
    font-weight: 500;
    font-family: 'Poppins';
    font-weight: 500;
    font-size: 24px;
    line-height: 1.5;
    color: #000000;
    text-transform: capitalize;
    margin: 0 0 20px 0;
}

.spice-starter-sites-importer-popup-container .spice-starter-sites-importer-buttons li {
    margin: 0;
  }

.spice-starter-sites-importer-popup-container .spice-starter-sites-importer-buttons{
    display: flex;
    gap: 20px;
    justify-content: center;
    margin: 0;
}
.spice-starter-sites-importer-popup-container .spice-starter-sites-importer-buttons a {
    text-decoration: none;
    font-family: 'Poppins';
    font-weight: 500;
    font-size: 16px;
    line-height: 1.5;
    display: block;
    width: 140px;
    height: 50px;
    line-height: 50px;
    border-radius: 6px;
    text-transform: uppercase;
    color: #FFF;
    -webkit-transition: background-color 0.2s;
    -moz-transition: background-color 0.2s;
    transition: background-color 0.2s;
}
.spice-starter-sites-importer-popup-container .spice-starter-sites-importer-buttons li:first-child a {
    background: #008D7F;
    color: #fff;
}
.no-touch .spice-starter-sites-importer-popup-container .spice-starter-sites-importer-buttons li:first-child a:hover {
  background-color: #fc8982;
}
.spice-starter-sites-importer-popup-container .spice-starter-sites-importer-buttons li:last-child a { 
    background: #9CB3B0;
     color: #fff;
}
.spice-starter-sites-importer-popup-container .spice-starter-sites-importer-buttons li a:hover{
    background: #2a2136; 
     color: #fff;
} 
.spice-starter-sites-importer-popup-container .spice-starter-sites-importer-popup-close {
    position: absolute;
    top: 15px;
    right: 15px;
    width: 20px;
    height: 20px;
    border: 1px solid #000000;
    border-radius: 50%;
}
.spice-starter-sites-importer-popup-container .spice-starter-sites-importer-popup-close::before, .spice-starter-sites-importer-popup-container .spice-starter-sites-importer-popup-close::after {
    content: '';
    position: absolute;
    top: 9px;
    width: 10px;
    height: 2px;
    background-color: #000000;
}
.spice-starter-sites-importer-popup-container .spice-starter-sites-importer-popup-close::before {
    -webkit-transform: rotate(45deg);
    -moz-transform: rotate(45deg);
    -ms-transform: rotate(45deg);
    -o-transform: rotate(45deg);
    transform: rotate(45deg);
    left: 5.5px;
}
.spice-starter-sites-importer-popup-container .spice-starter-sites-importer-popup-close::after {
    -webkit-transform: rotate(-45deg);
    -moz-transform: rotate(-45deg);
    -ms-transform: rotate(-45deg);
    -o-transform: rotate(-45deg);
    transform: rotate(-45deg);
    right: 4.5px;
}

#spice-starter-sites-importer-dashboard .block-container,.spice-starter-sites-importer-dashboard .theme_info .block-row{
    background: #fff;
    border: 1px solid #00a32a;
    border-left-width: 4px;
    box-shadow: 0 1px 1px rgba(0,0,0,.04);
    padding: 5px 12px;
    margin-top: 30px;
}
.spice-starter-sites-importer-button.button-primary {
    border-color: #ff495c;
    background: #ff495c;
    color: #FFFFFF;
}

.spice-starter-sites-importer-button.button-primary:hover,.spice-starter-sites-importer-button.button-primary:focus {
     border-color: #2a2136; 
    background: #2a2136; 
     color: #fff;
}
 .spice-starter-sites-importer-dashboard .block-col-2 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 100%;
    flex: 1;
    max-width: 100%;
}
.spice-starter-sites-importer-dashboard img{
    max-width: 100%;
    height: auto;
}


#spice-starter-sites-importer-dashboard .block-container{
    border: 2px solid #3a4995;
    padding: 0;
    position: relative;
}

#spice-starter-sites-importer-dashboard li {
    font-size: 16px;
    padding: 12px 10px 12px 3px
    font-weight: 500;
    line-height: 24px;
    color: #606060;
    position: relative;
    border-bottom: 1px solid #E0E0E0;
    text-align: left;
    margin: 0;
}
#spice-starter-sites-importer-dashboard li:last-child{
    border-bottom: none
}

#spice-starter-sites-importer-dashboard p{
    font-weight: 400;
    font-size: 16px;
    line-height: 1.5;
    color: #FFFFFF;
    padding: 0;
    margin: 0;
}

.spice-starter-sites-importer-button.button-primary{
    border: 1px solid #001F78;
    border-radius: 6px;
    font-style: normal;
    font-weight: 500;
    font-size: 16px;
    line-height: 24px;
    padding: 5px 32px;
    margin: 10px 0 0 8px;
    margin-right: 17px;
    color: #ffffff !important;
    background: linear-gradient(262.98deg, #001F78 1.43%, #002FB7 98.69%);
}
.spice-starter-sites-importer-button.button-second{
    border: 1px solid #001F78;
    border-radius: 6px;
    font-style: normal;
    font-weight: 500;
    font-size: 16px;
    line-height: 24px;
    padding: 5px 32px;
    margin: 10px 0 0 8px;
    margin-right: 17px;
    color: #ffffff !important;
    background:linear-gradient(262.98deg, #cbd2e6 1.43%, #6c91fa 98.69%);
}
.spice-starter-sites-importer-button.button-second:is(:hover, :focus){
    opacity: 0.8;
}
.spice-starter-sites-importer-button.button-primary:is(:hover, :focus){
    color: #ffffff !important;
    background: linear-gradient(262.98deg, #002FB7 1.43%, #001F78 98.69%);
    border: 1px solid #008D7F;
}
.spice-starter-sites-importer-button.button-primary.disabled:is(:hover, :focus){color: #a7aaad!important}
.importer-header{
    background: linear-gradient(262.98deg, #001F78 1.43%, #002FB7 98.69%);
    padding: 29px 48px 29px;
}

#spice-starter-sites-importer-dashboard .importer-body {
    padding:19px 50px 49px 39px ;
}

.wrap.spice-starter-sites-importer-dashboard .importer-header {
    padding: 20px 50px 24px;
}

.spice-starter-sites-importer-dashboard .importer-header h3{
    font-size: 1.625rem;
    line-height: 1.5;
    font-weight: 700;
    margin: 0 0 5px 0;
    color: #FFFFFF;  
}
.spice-starter-sites-importer-dashboard .importer-header span{
    font-weight: 400;
    font-size: 1rem;
    line-height: 1.5;
    color: #FFFFFF;  
    font-family: 'Poppins';
}

.wrap.spice-starter-sites-importer-dashboard .block-row{
    border: unset;
    padding: 0;
    margin: 0;
    margin-top: 30px;
    border: 2px solid #f0f0f0;
    box-shadow: 10px 10px 30px #e5e5e5;
}
.wrap.spice-starter-sites-importer-dashboard .block-row .block-col-2{
    padding: 0;
    height: 500px;
    overflow: hidden;
}

.wrap.spice-starter-sites-importer-dashboard .block-row .block-col-2:nth-of-type(2){
    background: #b6c8fc1c;
}

.wrap.spice-starter-sites-importer-dashboard .importer-body{
    padding: 30px 50px;
}

.wrap.spice-starter-sites-importer-dashboard .importer-body h4{
    font-weight: 600;
    font-size: 16px;
    line-height: 1.5;
    color: #000000;
    font-family: 'Poppins';
    margin: 17px 0;
}

#recommended_actions table{
    margin-top: 28px;
    margin-bottom: 24px;
}
#recommended_actions table tr{
    border-radius: 6px;
}

#recommended_actions table td{
    padding: 0;
    margin: 15px auto;
}

#recommended_actions table td:first-child{
    padding-left: 30px;
}

.wrap.spice-starter-sites-importer-dashboard .importer-body p,
#recommended_actions table td{
    font-weight: 400;
    font-size: 16px;
    line-height: 1.5;
    color: #505050;
    font-family: 'Poppins';
 }

#recommended_actions table td a.install-now,
#recommended_actions table td a.activate-now{
    font-weight: 500;
    font-size: 12px;
    color: #505050;
    line-height: 2.33333;
    border: 1px solid #001F78;
    background-color: transparent;
    border-radius: 6px;
    padding: 0 15px;
    font-family: 'Poppins';
    min-height: 30px !important;
}

#recommended_actions table td a.install-now:is(:hover, :focus), #recommended_actions table td a.activate-now:is(:hover, :focus) {
    color: #ffffff !important;
    background: linear-gradient(262.98deg, #002FB7 1.43%, #001F78 98.69%);
    border: 1px solid #002FB7;
}

.theme_info.info-tab-content .dashicons.dashicons-yes { 
    color: #008D7F;               
    font-size: 28px;       
    margin-right: 30px;
}

.wrap.spice-starter-sites-importer-dashboard .spice-starter-sites-importer-button.button-primary {
    margin: 0;
}
.wrap.spice-starter-sites-importer-dashboard .spice-starter-sites-importer-button.button-primary:nth-child(2) {
    margin: 0;
    margin-left: 16px;
}

.news-crunch-tab-pane .spice-starter-sites-importer-button.button-primary{
margin-left: 20px;
}

#loading-image{
    max-width: 475px;
}

#myDivs{
    max-width: 420px;
    margin: 0 auto;
    background-color: #b6c8fc1c;
    border-radius: 6px;
    padding: 0 40px 60px;
    margin-top: 114px;
}

#myDivs img{
    max-width: 130px;
    height: auto;
    margin-top: -65px;
    margin-bottom: 36px;
}

#myDivs h3{
    font-family: 'Poppins';
    font-style: normal;
    font-weight: 500;
    font-size: 36px;
    line-height: 46px;
    text-align: center;
    color: #000000;
    margin: 0;
}

#myDivs p{
    font-family: 'Poppins';
    font-style: normal;
    font-weight: 400;
    font-size: 16px;
    line-height: 26px;
    text-align: center;
    color: #505050;
    margin: 30px 0 42px;
}

/*#myDivs .spice-starter-sites-importer-button.button-primary{
    display: block;
    color: #FFFFFF;
    background: #008D7F;
}*/

#wpcontent {
    height: 100%;
    padding-left: 20px !important;
    padding-right: 20px !important;
}

#spice-starter-sites-importer-dashboard .spice-starter-sites-importer-sorry-msg {
    max-width: 480px;
    padding: 0 10px 40px;
    border-radius: 6px;
    background-color: rgb(120 120 120 / 5%);
    margin-top: 26px;
}

#spice-starter-sites-importer-dashboard .spice-starter-sites-importer-sorry-msg img{
    max-width: 100%;
    height: auto
}

#spice-starter-sites-importer-dashboard .spice-starter-sites-importer-sorry-msg span{
    display: block;
    font-size: 1.625rem;
    line-height: 1.5;
    font-weight: 700;
    margin: 0 0 10px 0;
    color: #000000; 
}
#spice-starter-sites-importer-dashboard .spice-starter-sites-importer-sorry-msg p{
    color: #000000;
}


@media (max-width:1120px){
    .wrap.spice-starter-sites-importer-dashboard .block-col-2:first-child{
        max-width: 40%;
        display: flex;
        align-items: center;
    }
    .wrap.spice-starter-sites-importer-dashboard .importer-body{
        padding: 30px 30px 52px;
    }
    .wrap.spice-starter-sites-importer-dashboard .importer-header {
        padding: 20px 30px 24px;
    }
}


@media (max-width:767px){
    .importer-header {
        background-color: #008D7F;
        padding: 29px 30px 29px;
    }
    #spice-starter-sites-importer-dashboard .importer-body {
        padding: 19px 30px 49px 20px;
    }
    .wrap.spice-starter-sites-importer-dashboard .block-container {
        max-width: 768px !important;}

    .wrap.spice-starter-sites-importer-dashboard .block-col-2:first-child{
        display: none;
    }
}

@media (max-width:447px){
     .wrap.spice-starter-sites-importer-dashboard .spice-starter-sites-importer-button.button-primary:nth-child(2) {
        margin: 0;
        margin-left: 0px;
        margin-top: 20px;
    }
}


/*Demo Pages Detail */

#sss-demo-section-inner .sss-library-content{
    padding-bottom: 15px;
}

.sss-card-details .sss-card-btn a.sss-preview{
    margin-right: 8px;
    color: #ffffff !important;
    background: linear-gradient(262.98deg, #001F78 1.43%, #002FB7 98.69%);
}

.sss-library-content .sss-back-btn a{
    text-decoration: none;
    color: #000;
}
.sss-library-content-wrapper .sss-content-section .sss-card .sss-starter-pack-inner-img{
    height:460px;
    overflow: hidden;
    background-size: 100% auto;
    transition: background-position 9s linear;
}
.sss-library-content-wrapper .sss-content-section .sss-card .sss-starter-pack-inner-img:hover{
    background-position: 0 100%;
}

.sss-library-body-wrapper .sss-library-content .sss-view-demo{
    text-align: center;
}

.sss-library-body-wrapper .sss-library-content .sss-view-demo a{
    display: block;
    font-family: 'Rubik';
    font-weight: 400;
    font-size: 16px;
    line-height: 50px;
    text-decoration: none;
    color: #000000;
    border: 1px solid #001F78;
    width: 150px;
    height: 50px;
    margin: 20px auto;
    /* transition: 0.2s; */
}
.sss-library-body-wrapper .sss-library-content .sss-view-demo a:hover{
    color: #ffffff;
    background: linear-gradient(262.98deg, #002FB7 1.43%, #001F78 98.69%);
}

/* Business Starter demo inner pag images */
.sss-library-content-wrapper.sss-business-starter-demo .sss-content-section .sss-card .sss-starter-pack-inner-img{
/*    background-image: url(../images/demo_images/Service.jpg);*/
    transition: background-position 5s linear;
}


.sss-library-body-wrapper .sss-library-content{
    height: 100%;
    flex: 1;
    padding: 9px 15px;
    overflow: auto;
    box-sizing: border-box;
    position: relative;
}
.sss-library-body-wrapper {
    display: flex;
    width: 100%;
    height: 100%;
}
.sss-library-content-wrapper{
    /*display: flex;
    flex-wrap: wrap;*/
    /* gap: 30px; */

}
.sss-library-body-wrapper .sss-content-section.sss-starter-pack{
 max-width: 100%;
    flex-basis: 100%
 }
@media (min-width:1600px){
.sss-library-body-wrapper .sss-content-section.sss-starter-pack{
 max-width: 25%;
    flex-basis: 25%
 }}
@media (max-width:1599px) and (min-width:1101px){
.sss-library-body-wrapper .sss-content-section.sss-starter-pack{
 max-width: 33.33%;
    flex-basis: 33.33%
 }}
 @media (max-width:1100px) and (min-width:768px){
.sss-library-body-wrapper .sss-content-section.sss-starter-pack{
 max-width: 50%;
    flex-basis: 50%
 }}
 .sss-library-body-wrapper .sss-content-section.sss-starter-pack .sss-card{
    background: #F3F6FE;
    transition: 0.3s;
    position: relative;
    margin-bottom: 50px;
    margin-right: 15px;
    display: block;
    height: auto;
    width:95%;
    box-shadow: 0px 10px 15px #c3c6cd;
}
.sss-heading h4{
    font-size: 1.25rem;
    line-height: 1.4;
    padding: 0 15px;
    color: #000;
    margin: 0;
    text-transform: capitalize;
}
.sss-content-section .sss-card .sss-card-details .sss-card-btn a {
    display: inline-block;
    font-family: 'Rubik';
    font-weight: 400;
    font-size: 16px;
    line-height: 26px;
    text-align: center;
    text-decoration: none;
    color: #000000;
    border: 1px solid #001F78;
    width: 75px;
    height: 27px;
    /* transition: 0.2s; */
    margin: 5px;
}

.sss-card-details .sss-card-btn a.sss-spice-block-preview {
    margin-right: 17px;
    color: #ffffff !important;
    background: linear-gradient(262.98deg, #001F78 1.43%, #002FB7 98.69%);
}
.sss-card-details .sss-heading{display: inline-block;}
.sss-card-details .sss-card-btn{
    position: relative;
/*    padding: 15px 8px;*/
    display: inline-block;
    text-align: right;
/*    padding-right: 10px;*/
}
.sss-library-heading h2{font-size: 1.25rem;color: #000;text-align: center;}
#spice-starter-sites-importer-dashboard .sss-library-heading p{color: #000;text-align: center;margin: 0 0 20px;}
 @media (max-width:500px){.sss-card-details .sss-card-btn {float: unset;}}


 /* Open theme demo popup*/

#sss_template_1 {
  position: fixed;
  top: 0px;
  left: 0px;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0,0.9);
  -webkit-transition: all 0.5s ease-in-out;
  -moz-transition: all 0.5s ease-in-out;
  -o-transition: all 0.5s ease-in-out;
  -ms-transition: all 0.5s ease-in-out;
  transition: all 0.5s ease-in-out;
  -webkit-transform: translate(0px, -100%) scale(0, 0);
  -moz-transform: translate(0px, -100%) scale(0, 0);
  -o-transform: translate(0px, -100%) scale(0, 0);
  -ms-transform: translate(0px, -100%) scale(0, 0);
  transform: translate(0px, -100%) scale(0, 0);
  opacity: 0;
  z-index: 11111111;
}
button.sss_block_close {
    position: absolute;
    right: 0;
    z-index: 2;
    padding-right: 1rem;
    padding-top: 0.6rem;
}
.sss_template .sss_block_close {
    position: absolute;
    top: -44px;
    right: -50px;
    color: #000000;
    background-color: #ffffff;
    opacity: 1;
    font-size: 1rem;
    z-index: 11111;
    cursor: pointer;
    font-weight: 700;
    padding: 10px 14px;
    line-height: 1;
    border-radius: 4px;
}

.sss_template i{
    padding-right: 5px;
  }
#sss_template_1.open {
  -webkit-transform: translate(0px, 0px) scale(1, 1);
  -moz-transform: translate(0px, 0px) scale(1, 1);
  -o-transform: translate(0px, 0px) scale(1, 1);
  -ms-transform: translate(0px, 0px) scale(1, 1);
  transform: translate(0px, 0px) scale(1, 1);
  opacity: 1;
}
.invisible{
     visibility: hidden;
}
.stater-badge{float: right;padding: 18px;position: relative;}
.sss-main #wpfooter {position: relative;}
@media (max-width:500px){.stater-badge {float: unset;padding: 0px 14px 14px;}}
.sss_template .sss_block_close:hover{
    color: #ffffff !important;
    background: linear-gradient(262.98deg, #001F78 1.43%, #002FB7 98.69%);
}
.stater-badge-new{
    position: absolute;
    bottom: 222px;
}
/* Business Starter demo inner pag images */


.sss-card-details {
    overflow: hidden;
    display: grid;
    grid-template-columns: 1fr 1fr;
    align-items: center;
    padding-block: 10px;
    min-height: 70px;
}
.tabs {
    display: flex;
    justify-content: center;
    background-color: #333;
}

.tab-button {
    padding: 14px 20px;
    cursor: pointer;
    background-color: #333;
    color: white;
    border: none;
    outline: none;
    transition: background-color 0.3s;
}

.tab-button:hover,
.tab-button.active {
    background-color: #555;
}

.tab-content {
    padding-block: 20px;
    display: flex;
    flex-wrap: wrap;
}

.tab-item {
    display: none; /* All items are hidden initially */
}

.tab-item.show {
    display: block; /* Show items when 'show' class is added */
}

/* Responsive design */
@media (max-width: 600px) {
    .tabs {
        flex-direction: column;
    }

    .tab-button {
        width: 100%;
        text-align: left;
    }
}
body.admin_page_spice-settings-importer{
   background-color: #fff;
}
body.admin_page_spice-settings-importer #wpbody-content {
    padding-bottom: 65px;
    float: left;
    width: 100%;
    overflow: visible;
}
.active-import-actions{
    position: fixed;
    z-index: 9999;
    background: white;
    width: 100%;
    bottom: 0;
    left: 0;
    display: flex;
    padding: 20px;
    justify-content: center;
    align-items: center;
    gap: 10px;
    box-shadow: 0 -4px 10px rgba(0, 0, 0, .3);
}
.active-import-actions .action-link.button span{
    display: none;
}

.active-import-actions .action-link.button{
   padding: 3px 45px 0px;
    border-radius: 2px;
    font-weight: 700;
    background: linear-gradient(262.98deg, #001F78 1.43%, #002FB7 98.69%);
    color: #fff;
}

.sss-card .sss-card-details {
    display: flex;
}

.sss-card .sss-card-details:not(:has(.sss-card-icon)) .sss-heading {
   padding-block: 25px;
}

.sss-card .sss-card-details .sss-heading{
    flex: 1;
}

.sss-card .sss-card-details .sss-card-icon{
    padding: 21px 13px;
    transition: opacity 0.2s ease-in-out  ;
}

.sss-card .sss-card-details .sss-card-btn{
    display: none;
    opacity: 0;
    transition: opacity 0.2s ease-in-out;
}

.sss-card:hover .sss-card-details .sss-card-btn{
    display: block;
    opacity: 1;
    padding: 15px 13px;
}

.sss-card:hover .sss-card-details .sss-card-icon{
    display: none;
    opacity: 0;
    visibility: hidden;
}
#starter_sites .active-import-actions #install-import-plugin-button-options-page{
    background: #ee591f;
    color: #fff;
    border-color: #ee591f;
    border-radius: 3px;
    padding: 2px 18px;
}
.sss-library-body-wrapper .sss-content-section.sss-starter-pack .sss-card.new:before{
    content:url('../../img/new2.png');
    position: absolute;
    top: 35px;
    right: -7px;
}
#recommended_actions .action-list .action img{
    vertical-align: middle;
    width: 100%;
    height: auto;
}

body.appearance_page_spicepress-welcome .spicepress-theme-notice{
    display: none;
}