.spicepress-actions-count {
    padding: 0 6px;
    display: inline-block;
    background-color: #d54e21;
    color: #fff;
    font-size: 9px;
    line-height: 17px;
    font-weight: 600;
    margin: 1px 0 0 2px;
    vertical-align: top;
    -webkit-border-radius: 10px;
    border-radius: 10px;
    z-index: 26;
}